@@ -439,20 +439,13 @@ let detachMenu ~button = _detachMenu (b2i button);;
 
  (* === GLUT window callback sub-API. === *)
 
-external _glutDisplayFunc : unit->unit = "ml_glutDisplayFunc"
-(* let displayFunc ~cb = setup "glutDisplayFunc" _glutDisplayFunc cb;; *)
-let displayFunc ~cb = 
-    let _ = Callback.register (cbname "glutDisplayFunc") cb in
-    _glutDisplayFunc (); (* register the callback with GLUT *)
-    ;;
+external displayFunc : cb:(unit->unit)->unit = "ml_glutDisplayFunc"
 
-external _glutReshapeFunc : unit->unit = "ml_glutReshapeFunc"
-let reshapeFunc ~cb = setup "glutReshapeFunc" _glutReshapeFunc cb;;
+external reshapeFunc : cb:(w:int->h:int->unit)->unit = "ml_glutReshapeFunc"
 
-external _glutKeyboardFunc : unit->unit = "ml_glutKeyboardFunc"
-let keyboardFunc ~cb = setup "glutKeyboardFunc" _glutKeyboardFunc cb;;
+external keyboardFunc : cb:(key:int->x:int->y:int->unit)->unit = "ml_glutKeyboardFunc"
 
-external _glutMouseFunc : unit->unit = "ml_glutMouseFunc"
+external _glutMouseFunc : cb:(int -> int -> int -> int -> unit)->unit = "ml_glutMouseFunc"
 let mouse_cb_wrapper user_func ibutton istate x y =
     let b = match ibutton with 
         | 0 -> LEFT_BUTTON 
@@ -465,43 +458,55 @@ let mouse_cb_wrapper user_func ibutton istate x y =
         | _ -> raise (BadEnum "istate in mouse_cb_wrapper") in
     user_func ~button:b ~state:s ~x ~y;;
 let mouseFunc ~cb =
-    setup "glutMouseFunc" _glutMouseFunc (mouse_cb_wrapper cb);;
+    _glutMouseFunc (mouse_cb_wrapper cb);;
 
-external _glutMotionFunc : unit->unit = "ml_glutMotionFunc"
-let motionFunc ~cb = setup "glutMotionFunc" _glutMotionFunc cb;;
+external motionFunc : cb:(x:int->y:int->unit)->unit = "ml_glutMotionFunc"
 
-external _glutPassiveMotionFunc : unit->unit = "ml_glutPassiveMotionFunc"
-let passiveMotionFunc ~cb = setup "glutPassiveMotionFunc" 
-  _glutPassiveMotionFunc cb;;
+external passiveMotionFunc : cb:(x:int->y:int->unit)->unit = "ml_glutPassiveMotionFunc"
 
-external _glutEntryFunc : unit->unit = "ml_glutEntryFunc" 
-let entryFunc ~cb = setup "glutEntryFunc" _glutEntryFunc cb;;
-    
-external _glutVisibilityFunc:unit->unit="ml_glutVisibilityFunc"
-let visibilityFunc ~cb = setup "glutVisibilityFunc" _glutVisibilityFunc cb;;
+external entryFunc : cb:(state:entry_exit_state_t->unit)->unit = "ml_glutEntryFunc" 
+
+external visibilityFunc : cb:(state:visibility_state_t->unit)->unit = "ml_glutVisibilityFunc"
 
 (* idleFunc is for the entire program, not just a single window,
    so its name does not depend on the window id *)
-external _glutIdleFunc:unit->unit="ml_glutIdleFunc"
+external _glutIdleFunc:(unit->unit)->unit="ml_glutIdleFunc"
+
 external _setIdleFuncToNull:unit->unit="ml_glutSetIdleFuncToNull"
 let idleFunc ~cb = 
     match cb with 
     | None -> _setIdleFuncToNull();
-    | Some callback -> 
+    | Some cb -> 
       begin
-        Callback.register "ocaml_glutIdleFunc" callback;
-        _glutIdleFunc();
+        _glutIdleFunc cb;
       end
 ;;
 
 (* timerFunc is non-window-dependent *)
-external _glutTimerFunc : int->int->unit = "ml_glutTimerFunc"
-let timerFunc ~ms ~cb ~value:v : (unit) =
-    let _ = Callback.register "ocaml_glutTimerFunc" cb in
-    _glutTimerFunc ms v;; (* register the callback with GLUT *)
 
-external _glutMenuStateFunc:unit->unit="ml_glutMenuStateFunc"
-let menuStateFunc ~cb = setup "glutMenuStateFunc" _glutMenuStateFunc cb;;
+external _timerFunc : int -> int -> unit = "ml_glutTimerFunc"
+
+external init_timerFunc : (int -> unit) -> unit = "init_glutTimerFunc_cb"
+
+let timer_hashtbl = Hashtbl.create 101
+
+let real_call_back i = 
+  Hashtbl.find timer_hashtbl i ()
+
+let _ = 
+  init_timerFunc real_call_back
+
+let timer_count = ref 0 
+
+let timerFunc ~ms ~cb:(cb:(value:'a -> unit)) ~value =
+    let i = !timer_count in
+    incr timer_count;
+    Hashtbl.add timer_hashtbl i (fun () -> 
+      Hashtbl.remove timer_hashtbl i; 
+      cb value);
+    _timerFunc ms i
+
+external menuStateFunc : cb:(status:menu_state_t->unit)->unit = "ml_glutMenuStateFunc"
 
 let special_of_int i = match i with
   | 1 -> KEY_F1    (* values from glut.h *)
@@ -527,40 +532,28 @@ let special_of_int i = match i with
   | 108 -> KEY_INSERT    
   | _ -> raise (BadEnum "key in special_of_int");;
 
-external _glutSpecialFunc : unit->unit = "ml_glutSpecialFunc"
+external _glutSpecialFunc : (key:int->x:int->y:int->unit)->unit = "ml_glutSpecialFunc"
 let specialFunc ~cb =
-  setup "glutSpecialFunc" _glutSpecialFunc 
+  _glutSpecialFunc 
       (fun ~key ~x ~y -> cb ~key:(special_of_int key) ~x ~y) ;;
 
-external _spaceballMotionFunc: unit->unit = "ml_glutSpaceballMotionFunc"
-let spaceballMotionFunc ~cb = 
-  setup "glutSpaceballMotionFunc" _spaceballMotionFunc cb;;
+external spaceballMotionFunc: cb:(x:int->y:int->z:int->unit)->unit = "ml_glutSpaceballMotionFunc"
 
-external _spaceballRotateFunc: unit->unit = "ml_glutSpaceballRotateFunc"
-let spaceballRotateFunc ~cb = 
-  setup "glutSpaceballRotateFunc" _spaceballRotateFunc cb;;
+external spaceballRotateFunc: cb:(x:int->y:int->z:int->unit)->unit = "ml_glutSpaceballRotateFunc"
 
-external _spaceballButtonFunc: unit->unit = "ml_glutSpaceballButtonFunc"
-let spaceballButtonFunc ~cb = 
-  setup "glutSpaceballButtonFunc" _spaceballButtonFunc cb;;
+external spaceballButtonFunc: cb:(button:int->state:int->unit)->unit = "ml_glutSpaceballButtonFunc"
 
-external _buttonBoxFunc: unit->unit = "ml_glutButtonBoxFunc"
-let buttonBoxFunc ~cb = setup "glutButtonBoxFunc" _buttonBoxFunc cb;;
+external buttonBoxFunc: cb:(button:int->state:int->unit)->unit = "ml_glutButtonBoxFunc"
 
-external _dialsFunc: unit->unit = "ml_glutDialsFunc"
-let dialsFunc ~cb = setup "glutDialsFunc" _dialsFunc cb;;
+external dialsFunc: cb:(dial:int->value:int->unit)->unit = "ml_glutDialsFunc"
 
-external _tabletMotionFunc: unit->unit = "ml_glutTabletMotionFunc"
-let tabletMotionFunc ~cb = setup "glutTabletMotionFunc" _tabletMotionFunc cb;;
+external tabletMotionFunc: cb:(x:int->y:int->unit)->unit = "ml_glutTabletMotionFunc"
 
-external _tabletButtonFunc: unit->unit = "ml_glutTabletButtonFunc"
-let tabletButtonFunc ~cb = setup "glutTabletButtonFunc" _tabletButtonFunc cb;;
+external tabletButtonFunc: cb:(button:int->state:int->x:int->y:int->unit)->unit = "ml_glutTabletButtonFunc"
 
-external _menuStatusFunc: unit->unit = "ml_glutMenuStatusFunc"
-let menuStatusFunc ~cb = setup "glutMenuStatusFunc" _menuStatusFunc cb;;
+external menuStatusFunc: cb:(status:menu_state_t->x:int->y:int->unit)->unit = "ml_glutMenuStatusFunc"
 
-external _overlayDisplayFunc:unit->unit = "ml_glutOverlayDisplayFunc"
-let overlayDisplayFunc ~cb = setup "glutOverlayDisplayFunc" _overlayDisplayFunc cb;;
+external overlayDisplayFunc:cb:(unit->unit)->unit = "ml_glutOverlayDisplayFunc"
 
  (* === GLUT color index sub-API. === === *)
 external setColor: cell:int->red:float->green:float->blue:float->unit = 
@@ -757,9 +750,9 @@ let bitmapLength ~font ~str = _bitmapLength (f2i font) str;;
 external _strokeLength: font:int->str:string->int = "ml_glutStrokeLength"
 let strokeLength ~font ~str = _strokeLength (f2i font) str;;
 
-external _windowStatusFunc: unit->unit = "ml_glutWindowStatusFunc"
+external _windowStatusFunc: (int->unit)->unit = "ml_glutWindowStatusFunc"
 let windowStatusFunc ~cb = 
-  setup "glutWindowStatusFunc" _windowStatusFunc  
+  _windowStatusFunc  
    (fun s -> 
     cb ~state:(match s with
       | 0 -> HIDDEN 
@@ -775,12 +768,11 @@ external postWindowRedisplay: win:int->unit =
 external postWindowOverlayRedisplay: win:int->unit = 
   "ml_glutPostWindowOverlayRedisplay"
 
-external _keyboardUpFunc: unit->unit = "ml_glutKeyboardUpFunc"
-let keyboardUpFunc ~cb = setup "glutKeyboardUpFunc" _keyboardUpFunc cb;;
+external keyboardUpFunc: cb:(key:int->x:int->y:int->unit)->unit = "ml_glutKeyboardUpFunc"
 
-external _glutSpecialUpFunc : unit->unit = "ml_glutSpecialUpFunc"
+external _glutSpecialUpFunc : (key:int->x:int->y:int->unit)->unit = "ml_glutSpecialUpFunc"
 let specialUpFunc ~cb =
-  setup "glutSpecialUpFunc" _glutSpecialUpFunc 
+  _glutSpecialUpFunc 
       (fun ~key ~x ~y -> cb ~key:(special_of_int key) ~x ~y) ;;
 
 external _ignoreKeyRepeat: ignore:int->unit = "ml_glutIgnoreKeyRepeat"
@@ -794,10 +786,8 @@ let setKeyRepeat ~mode =
     | KEY_REPEAT_DEFAULT -> 2
   );;
 
-external _joystickFunc: pollInterval:int->unit = "ml_glutJoystickFunc" 
-let joystickFunc ~cb ~pollInterval = 
-  let _ = Callback.register (cbname "glutJoystickFunc") cb in
-  _joystickFunc ~pollInterval;;
+external joystickFunc: cb:(buttonMask:int->x:int->y:int->z:int->unit)->
+  pollInterval:int->unit = "ml_glutJoystickFunc" 
 
 external forceJoystickFunc: unit->unit = "ml_glutForceJoystickFunc"
 
