@@ -11,7 +11,7 @@
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * RCS: $Id: tkInt8.4.h,v 1.1 2003/01/09 08:25:14 garrigue Exp $ 
+ * RCS: $Id: tkInt8.2.h,v 1.1 1999/08/05 02:07:26 garrigue Exp $ 
  */
 
 #ifndef _TKINT
@@ -33,6 +33,7 @@
 
 typedef struct TkColormap TkColormap;
 typedef struct TkGrabEvent TkGrabEvent;
+typedef struct Tk_PostscriptInfo Tk_PostscriptInfo;
 typedef struct TkpCursor_ *TkpCursor;
 typedef struct TkRegion_ *TkRegion;
 typedef struct TkStressedCmap TkStressedCmap;
@@ -46,6 +47,32 @@ typedef int (TkBindEvalProc) _ANSI_ARGS_((ClientData clientData,
 	Tcl_Interp *interp, XEvent *eventPtr, Tk_Window tkwin,
 	KeySym keySym));
 typedef void (TkBindFreeProc) _ANSI_ARGS_((ClientData clientData));
+typedef Window (TkClassCreateProc) _ANSI_ARGS_((Tk_Window tkwin,
+	Window parent, ClientData instanceData));
+typedef void (TkClassGeometryProc) _ANSI_ARGS_((ClientData instanceData));
+typedef void (TkClassModalProc) _ANSI_ARGS_((Tk_Window tkwin,
+	XEvent *eventPtr));
+
+
+/*
+ * Widget class procedures used to implement platform specific widget
+ * behavior.
+ */
+
+typedef struct TkClassProcs {
+    TkClassCreateProc *createProc;
+				/* Procedure to invoke when the
+                                   platform-dependent window needs to be
+                                   created. */
+    TkClassGeometryProc *geometryProc;
+				/* Procedure to invoke when the geometry of a
+				   window needs to be recalculated as a result
+				   of some change in the system. */
+    TkClassModalProc *modalProc;
+				/* Procedure to invoke after all bindings on a
+				   widget have been triggered in order to
+				   handle a modal loop. */
+} TkClassProcs;
 
 /*
  * One of the following structures is maintained for each cursor in
@@ -81,31 +108,6 @@ typedef struct TkCursor {
 				 * together off a single hash table entry. */
 } TkCursor;
 
-/*
- * This defines whether we should try to use XIM over-the-spot style
- * input.  Allow users to override it.  It is a much more elegant use
- * of XIM, but uses a bit more memory.
- */
-
-#ifndef TK_XIM_SPOT
-#   define TK_XIM_SPOT	1
-#endif
-
-/*
- * The following structure is kept one-per-TkDisplay to maintain information
- * about the caret (cursor location) on this display.  This is used to
- * dictate global focus location (Windows Accessibility guidelines) and to
- * position the IME or XIM over-the-spot window.
- */
-
-typedef struct TkCaret {
-    struct TkWindow *winPtr;	/* the window on which we requested caret
-				 * placement */
-    int x;			/* relative x coord of the caret */
-    int y;			/* relative y coord of the caret */
-    int height;			/* specified height of the window */
-} TkCaret;
-
 /*
  * One of the following structures is maintained for each display
  * containing a window managed by Tk.  In part, the structure is 
@@ -394,7 +396,6 @@ typedef struct TkDisplay {
     Atom applicationAtom;	/* Atom for TK_APPLICATION. */
     Atom windowAtom;		/* Atom for TK_WINDOW. */
     Atom clipboardAtom;		/* Atom for CLIPBOARD. */
-    Atom utf8Atom;		/* Atom for UTF8_STRING. */
 
     Tk_Window clipWindow;	/* Window used for clipboard ownership and to
 				 * retrieve selections between processes. NULL
@@ -438,15 +439,19 @@ typedef struct TkDisplay {
 				/* First in list of chunks of window
 				 * identifers that can't be reused right
 				 * now. */
-    Tcl_TimerToken idCleanupScheduled;
-				/* If set, it means a call to WindowIdCleanup
-				 * has already been scheduled, 0 means it
+    int idCleanupScheduled;	/* 1 means a call to WindowIdCleanup has
+				 * already been scheduled, 0 means it
 				 * hasn't. */
 
     /*
      * Information used by tkUnixWm.c and tkWinWm.c only:
      */
 
+    int wmTracing;              /* Used to enable or disable tracing in 
+				 * this module.  If tracing is enabled, 
+				 * then information is printed on
+				 * standard output about interesting 
+				 * interactions with the window manager. */
     struct TkWmInfo *firstWmPtr;  /* Points to first top-level window. */
     struct TkWmInfo *foregroundWmPtr;    
                                 /* Points to the foreground window. */
@@ -477,9 +482,6 @@ typedef struct TkDisplay {
 
 #ifdef TK_USE_INPUT_METHODS
     XIM inputMethod;		/* Input method for this display */
-#if TK_XIM_SPOT
-    XFontSet inputXfs;		/* XFontSet cached for over-the-spot XIM. */
-#endif
 #endif /* TK_USE_INPUT_METHODS */
     Tcl_HashTable winTable;	/* Maps from X window ids to TkWindow ptrs. */
 
@@ -488,45 +490,8 @@ typedef struct TkDisplay {
                                  * the display when we no longer have any
                                  * Tk applications using it.
                                  */
-    /*
-     * The following field were all added for Tk8.3
-     */
-    int mouseButtonState;	/* current mouse button state for this
-				 * display */
-    Window warpWindow;
-    int warpX;
-    int warpY;
-
-    /*
-     * The following field(s) were all added for Tk8.4
-     */
-    long deletionEpoch;		/* Incremented by window deletions */
-    unsigned int flags;		/* Various flag values:  these are all
-				 * defined in below. */
-    TkCaret caret;		/* information about the caret for this
-				 * display.  This is not a pointer. */
 } TkDisplay;
 
-/*
- * Flag values for TkDisplay flags.
- *  TK_DISPLAY_COLLAPSE_MOTION_EVENTS:	(default on)
- *	Indicates that we should collapse motion events on this display
- *  TK_DISPLAY_USE_IM:			(default on, set via tk.tcl)
- *	Whether to use input methods for this display
- *  TK_DISPLAY_XIM_SPOT:		(default off)
- *	Indicates that we should use over-the-spot XIM on this display
- *  TK_DISPLAY_WM_TRACING:		(default off)
- *	Whether we should do wm tracing on this display.
- *  TK_DISPLAY_IN_WARP:			(default off)
- *	Indicates that we are in a pointer warp
- */
-
-#define TK_DISPLAY_COLLAPSE_MOTION_EVENTS	(1 << 0)
-#define TK_DISPLAY_USE_IM			(1 << 1)
-#define TK_DISPLAY_XIM_SPOT			(1 << 2)
-#define TK_DISPLAY_WM_TRACING			(1 << 3)
-#define TK_DISPLAY_IN_WARP			(1 << 4)
-
 /*
  * One of the following structures exists for each error handler
  * created by a call to Tk_CreateErrorHandler.  The structure
@@ -563,6 +528,8 @@ typedef struct TkErrorHandler {
 } TkErrorHandler;
 
 
+
+
 /*
  * One of the following structures exists for each event handler
  * created by calling Tk_CreateEventHandler.  This information
@@ -643,7 +610,7 @@ typedef struct TkMainInfo {
  */
 
 typedef struct {
-    CONST char *source;		/* Bits for bitmap. */
+    char *source;		/* Bits for bitmap. */
     int width, height;		/* Dimensions of bitmap. */
     int native;			/* 0 means generic (X style) bitmap,
     				 * 1 means native style bitmap. */
@@ -744,7 +711,7 @@ typedef struct TkWindow {
 				 * declared for this window, or
 				 * NULL if none. */
 #ifdef TK_USE_INPUT_METHODS
-    XIC inputContext;		/* XIM input context. */
+    XIC inputContext;		/* Input context (for input methods). */
 #endif /* TK_USE_INPUT_METHODS */
 
     /*
@@ -787,12 +754,10 @@ typedef struct TkWindow {
 				 * Tk_GeometryRequest, or 0's if
 				 * Tk_GeometryRequest hasn't been
 				 * called. */
-    int internalBorderLeft;	/* Width of internal border of window
+    int internalBorderWidth;	/* Width of internal border of window
 				 * (0 means no internal border).  Geometry
 				 * managers should not normally place children
-				 * on top of the border. 
-				 * Fields for the other three sides are found 
-				 * below. */
+				 * on top of the border. */
 
     /*
      * Information maintained by tkWm.c for window manager communication.
@@ -808,7 +773,7 @@ typedef struct TkWindow {
      * Information used by widget classes.
      */
 
-    Tk_ClassProcs *classProcsPtr;
+    TkClassProcs *classProcsPtr;
     ClientData instanceData;
 
     /*
@@ -816,18 +781,6 @@ typedef struct TkWindow {
      */
 
     struct TkWindowPrivate *privatePtr;
-
-    /*
-     * More information used by tkGeometry.c for geometry management.
-     */
-
-    /* The remaining fields of internal border. */
-    int internalBorderRight; 
-    int internalBorderTop;
-    int internalBorderBottom;
-    
-    int minReqWidth;		/* Minimum requested width. */
-    int minReqHeight;		/* Minimum requested height. */
 } TkWindow;
 
 /*
@@ -888,45 +841,25 @@ extern TkDisplay *tkDisplayList;
 
 #define EMBEDDED_APP_WANTS_FOCUS (NotifyNormal + 20)
 
-/*
- * The following special modifier mask bits are defined, to indicate
- * logical modifiers such as Meta and Alt that may float among the
- * actual modifier bits.
- */
-
-#define META_MASK	(AnyModifier<<1)
-#define ALT_MASK	(AnyModifier<<2)
-
-/*
- * Object types not declared in tkObj.c need to be mentioned here so
- * they can be properly registered with Tcl:
- */
-
-extern Tcl_ObjType tkBorderObjType;
-extern Tcl_ObjType tkBitmapObjType;
-extern Tcl_ObjType tkColorObjType;
-extern Tcl_ObjType tkCursorObjType;
-extern Tcl_ObjType tkFontObjType;
-extern Tcl_ObjType tkOptionObjType;
-extern Tcl_ObjType tkStateKeyObjType;
-
 /*
  * Miscellaneous variables shared among Tk modules but not exported
  * to the outside world:
  */
 
-extern Tk_SmoothMethod		tkBezierSmoothMethod;
+extern Tk_Uid			tkActiveUid;
 extern Tk_ImageType		tkBitmapImageType;
+extern Tk_Uid			tkDisabledUid;
 extern Tk_PhotoImageFormat	tkImgFmtGIF;
 extern void			(*tkHandleEventProc) _ANSI_ARGS_((
     				    XEvent* eventPtr));
 extern Tk_PhotoImageFormat	tkImgFmtPPM;
 extern TkMainInfo		*tkMainWindowList;
+extern Tk_Uid			tkNormalUid;
 extern Tk_ImageType		tkPhotoImageType;
 extern Tcl_HashTable		tkPredefBitmapTable;
 extern int			tkSendSerial;
 
-#include "tkIntDecls8.4.h"
+#include "tkIntDecls8.2.h"
 
 #ifdef BUILD_tk
 # undef TCL_STORAGE_CLASS
@@ -938,28 +871,25 @@ extern int			tkSendSerial;
  * to the outside world:
  */
 
+EXTERN int		Tk_AfterCmd _ANSI_ARGS_((ClientData clientData,
+			    Tcl_Interp *interp, int argc, char **argv));
 EXTERN int		Tk_BellObjCmd _ANSI_ARGS_((ClientData clientData,
 			    Tcl_Interp *interp, int objc, 
 			    Tcl_Obj *CONST objv[]));
-EXTERN int		Tk_BindObjCmd _ANSI_ARGS_((ClientData clientData,
-			    Tcl_Interp *interp, int objc,
-			    Tcl_Obj *CONST objv[]));
-EXTERN int		Tk_BindtagsObjCmd _ANSI_ARGS_((ClientData clientData,
-			    Tcl_Interp *interp, int objc,
-			    Tcl_Obj *CONST objv[]));
+EXTERN int		Tk_BindCmd _ANSI_ARGS_((ClientData clientData,
+			    Tcl_Interp *interp, int argc, char **argv));
+EXTERN int		Tk_BindtagsCmd _ANSI_ARGS_((ClientData clientData,
+			    Tcl_Interp *interp, int argc, char **argv));
 EXTERN int		Tk_ButtonObjCmd _ANSI_ARGS_((ClientData clientData,
 			    Tcl_Interp *interp, int objc,
 			    Tcl_Obj *CONST objv[]));
-EXTERN int		Tk_CanvasObjCmd _ANSI_ARGS_((ClientData clientData,
-			    Tcl_Interp *interp, int argc,
-			    Tcl_Obj *CONST objv[]));
-EXTERN int		Tk_CheckbuttonObjCmd _ANSI_ARGS_((
-			    ClientData clientData,
+EXTERN int		Tk_CanvasCmd _ANSI_ARGS_((ClientData clientData,
+			    Tcl_Interp *interp, int argc, char **argv));
+EXTERN int		Tk_CheckbuttonObjCmd _ANSI_ARGS_((ClientData clientData,
 			    Tcl_Interp *interp, int objc,
 			    Tcl_Obj *CONST objv[]));
-EXTERN int              Tk_ClipboardObjCmd _ANSI_ARGS_((
-			    ClientData clientData, Tcl_Interp *interp,
-			    int objc, Tcl_Obj *CONST objv[]));
+EXTERN int		Tk_ClipboardCmd _ANSI_ARGS_((ClientData clientData,
+			    Tcl_Interp *interp, int argc, char **argv));
 EXTERN int              Tk_ChooseColorObjCmd _ANSI_ARGS_((
 			    ClientData clientData, Tcl_Interp *interp,
 			    int objc, Tcl_Obj *CONST objv[]));
@@ -969,9 +899,8 @@ EXTERN int              Tk_ChooseDirectoryObjCmd _ANSI_ARGS_((
 EXTERN int              Tk_ChooseFontObjCmd _ANSI_ARGS_((ClientData clientData,
 			    Tcl_Interp *interp, int objc, 
 			    Tcl_Obj *CONST objv[]));
-EXTERN int		Tk_DestroyObjCmd _ANSI_ARGS_((ClientData clientData,
-			    Tcl_Interp *interp, int objc, 
-			    Tcl_Obj *CONST objv[]));
+EXTERN int		Tk_DestroyCmd _ANSI_ARGS_((ClientData clientData,
+			    Tcl_Interp *interp, int argc, char **argv));
 EXTERN int		Tk_EntryObjCmd _ANSI_ARGS_((ClientData clientData,
 			    Tcl_Interp *interp, int objc, 
                             Tcl_Obj *CONST objv[]));
@@ -980,196 +909,99 @@ EXTERN int		Tk_EventObjCmd _ANSI_ARGS_((ClientData clientData,
 			    Tcl_Obj *CONST objv[]));
 EXTERN int		Tk_FileeventCmd _ANSI_ARGS_((ClientData clientData,
 			    Tcl_Interp *interp, int argc, char **argv));
-EXTERN int		Tk_FrameObjCmd _ANSI_ARGS_((ClientData clientData,
-			    Tcl_Interp *interp, int objc,
-			    Tcl_Obj *CONST objv[]));
+EXTERN int		Tk_FrameCmd _ANSI_ARGS_((ClientData clientData,
+			    Tcl_Interp *interp, int argc, char **argv));
 EXTERN int		Tk_FocusObjCmd _ANSI_ARGS_((ClientData clientData,
 			    Tcl_Interp *interp, int objc, 
 			    Tcl_Obj *CONST objv[]));
 EXTERN int		Tk_FontObjCmd _ANSI_ARGS_((ClientData clientData,
 			    Tcl_Interp *interp, int objc, 
 			    Tcl_Obj *CONST objv[]));
-EXTERN int              Tk_GetOpenFileObjCmd _ANSI_ARGS_((
-			    ClientData clientData,
+EXTERN int              Tk_GetOpenFileObjCmd _ANSI_ARGS_((ClientData clientData,
 			    Tcl_Interp *interp, int objc, 
 			    Tcl_Obj *CONST objv[]));
-EXTERN int              Tk_GetSaveFileObjCmd _ANSI_ARGS_((
-			    ClientData clientData,
-			    Tcl_Interp *interp, int objc, 
-			    Tcl_Obj *CONST objv[]));
-EXTERN int		Tk_GrabObjCmd _ANSI_ARGS_((ClientData clientData,
-			    Tcl_Interp *interp, int objc,
-			    Tcl_Obj *CONST objv[]));
-EXTERN int		Tk_GridObjCmd _ANSI_ARGS_((ClientData clientData,
-			    Tcl_Interp *interp, int objc,
-			    Tcl_Obj *CONST objv[]));
-EXTERN int		Tk_ImageObjCmd _ANSI_ARGS_((ClientData clientData,
+EXTERN int              Tk_GetSaveFileObjCmd _ANSI_ARGS_((ClientData clientData,
 			    Tcl_Interp *interp, int objc, 
 			    Tcl_Obj *CONST objv[]));
+EXTERN int		Tk_GrabCmd _ANSI_ARGS_((ClientData clientData,
+			    Tcl_Interp *interp, int argc, char **argv));
+EXTERN int		Tk_GridCmd _ANSI_ARGS_((ClientData clientData,
+			    Tcl_Interp *interp, int argc, char **argv));
+EXTERN int		Tk_ImageCmd _ANSI_ARGS_((ClientData clientData,
+			    Tcl_Interp *interp, int argc, char **argv));
 EXTERN int		Tk_LabelObjCmd _ANSI_ARGS_((ClientData clientData,
 			    Tcl_Interp *interp, int objc,
 			    Tcl_Obj *CONST objv[]));
-EXTERN int		Tk_LabelframeObjCmd _ANSI_ARGS_((ClientData clientData,
-			    Tcl_Interp *interp, int objc,
-			    Tcl_Obj *CONST objv[]));
-EXTERN int		Tk_ListboxObjCmd _ANSI_ARGS_((ClientData clientData,
-			    Tcl_Interp *interp, int objc,
-			    Tcl_Obj *CONST objv[]));
-EXTERN int		Tk_LowerObjCmd _ANSI_ARGS_((ClientData clientData,
-			    Tcl_Interp *interp, int objc,
-			    Tcl_Obj *CONST objv[]));
+EXTERN int		Tk_ListboxCmd _ANSI_ARGS_((ClientData clientData,
+			    Tcl_Interp *interp, int argc, char **argv));
+EXTERN int		Tk_LowerCmd _ANSI_ARGS_((ClientData clientData,
+			    Tcl_Interp *interp, int argc, char **argv));
 EXTERN int		Tk_MenubuttonObjCmd _ANSI_ARGS_((ClientData clientData,
 			    Tcl_Interp *interp, int objc, 
 			    Tcl_Obj *CONST objv[]));
 EXTERN int              Tk_MessageBoxObjCmd _ANSI_ARGS_((ClientData clientData,
                             Tcl_Interp *interp, int objc, 
 			    Tcl_Obj *CONST objv[]));
-EXTERN int		Tk_MessageObjCmd _ANSI_ARGS_((ClientData clientData,
-			    Tcl_Interp *interp, int objc,
-			    Tcl_Obj *CONST objv[]));
-EXTERN int		Tk_PanedWindowObjCmd _ANSI_ARGS_((
-			    ClientData clientData,
-			    Tcl_Interp *interp, int objc,
-			    Tcl_Obj *CONST objv[]));
-EXTERN int		Tk_OptionObjCmd _ANSI_ARGS_((ClientData clientData,
-			    Tcl_Interp *interp, int objc,
-	                    Tcl_Obj *CONST objv[]));
-EXTERN int		Tk_PackObjCmd _ANSI_ARGS_((ClientData clientData,
-			    Tcl_Interp *interp, int objc,
-			    Tcl_Obj *CONST objv[]));
-EXTERN int		Tk_PlaceObjCmd _ANSI_ARGS_((ClientData clientData,
-			    Tcl_Interp *interp, int objc,
-			    Tcl_Obj *CONST objv[]));
-EXTERN int		Tk_RadiobuttonObjCmd _ANSI_ARGS_((
-			    ClientData clientData,
-			    Tcl_Interp *interp, int objc,
-			    Tcl_Obj *CONST objv[]));
-EXTERN int		Tk_RaiseObjCmd _ANSI_ARGS_((ClientData clientData,
+EXTERN int		Tk_MessageCmd _ANSI_ARGS_((ClientData clientData,
+			    Tcl_Interp *interp, int argc, char **argv));
+EXTERN int		Tk_OptionCmd _ANSI_ARGS_((ClientData clientData,
+			    Tcl_Interp *interp, int argc, char **argv));
+EXTERN int		Tk_PackCmd _ANSI_ARGS_((ClientData clientData,
+			    Tcl_Interp *interp, int argc, char **argv));
+EXTERN int		Tk_PlaceCmd _ANSI_ARGS_((ClientData clientData,
+			    Tcl_Interp *interp, int argc, char **argv));
+EXTERN int		Tk_RadiobuttonObjCmd _ANSI_ARGS_((ClientData clientData,
 			    Tcl_Interp *interp, int objc,
 			    Tcl_Obj *CONST objv[]));
+EXTERN int		Tk_RaiseCmd _ANSI_ARGS_((ClientData clientData,
+			    Tcl_Interp *interp, int argc, char **argv));
 EXTERN int		Tk_ScaleObjCmd _ANSI_ARGS_((ClientData clientData,
 			    Tcl_Interp *interp, int objc, 
                             Tcl_Obj *CONST objv[]));
 EXTERN int		Tk_ScrollbarCmd _ANSI_ARGS_((ClientData clientData,
-			    Tcl_Interp *interp, int argc, CONST char **argv));
-EXTERN int		Tk_SelectionObjCmd _ANSI_ARGS_((ClientData clientData,
-			    Tcl_Interp *interp, int objc,
-			    Tcl_Obj *CONST objv[]));
+			    Tcl_Interp *interp, int argc, char **argv));
+EXTERN int		Tk_SelectionCmd _ANSI_ARGS_((ClientData clientData,
+			    Tcl_Interp *interp, int argc, char **argv));
 EXTERN int		Tk_SendCmd _ANSI_ARGS_((ClientData clientData,
-			    Tcl_Interp *interp, int argc, CONST char **argv));
+			    Tcl_Interp *interp, int argc, char **argv));
 EXTERN int		Tk_SendObjCmd _ANSI_ARGS_((ClientData clientData,
 			    Tcl_Interp *interp, int objc, 
 			    Tcl_Obj *CONST objv[]));
-EXTERN int		Tk_SpinboxObjCmd _ANSI_ARGS_((ClientData clientData,
-			    Tcl_Interp *interp, int objc, 
-                            Tcl_Obj *CONST objv[]));
 EXTERN int		Tk_TextCmd _ANSI_ARGS_((ClientData clientData,
-			    Tcl_Interp *interp, int argc, CONST char **argv));
+			    Tcl_Interp *interp, int argc, char **argv));
 EXTERN int		Tk_TkObjCmd _ANSI_ARGS_((ClientData clientData,
 			    Tcl_Interp *interp, int objc,
 			    Tcl_Obj *CONST objv[]));
-EXTERN int		Tk_TkwaitObjCmd _ANSI_ARGS_((ClientData clientData,
-			    Tcl_Interp *interp, int objc,
-			    Tcl_Obj *CONST objv[]));
-EXTERN int		Tk_ToplevelObjCmd _ANSI_ARGS_((ClientData clientData,
-			    Tcl_Interp *interp, int objc,
-			    Tcl_Obj *CONST objv[]));
+EXTERN int		Tk_TkwaitCmd _ANSI_ARGS_((ClientData clientData,
+			    Tcl_Interp *interp, int argc, char **argv));
+EXTERN int		Tk_ToplevelCmd _ANSI_ARGS_((ClientData clientData,
+			    Tcl_Interp *interp, int argc, char **argv));
 EXTERN int		Tk_UpdateObjCmd _ANSI_ARGS_((ClientData clientData,
 			    Tcl_Interp *interp, int objc, 
 			    Tcl_Obj *CONST objv[]));
 EXTERN int		Tk_WinfoObjCmd _ANSI_ARGS_((ClientData clientData,
 			    Tcl_Interp *interp, int objc,
 			    Tcl_Obj *CONST objv[]));
-EXTERN int		Tk_WmObjCmd _ANSI_ARGS_((ClientData clientData,
-			    Tcl_Interp *interp, int objc,
-			    Tcl_Obj *CONST objv[]));
+EXTERN int		Tk_WmCmd _ANSI_ARGS_((ClientData clientData,
+			    Tcl_Interp *interp, int argc, char **argv));
 
-EXTERN void		TkConsolePrint _ANSI_ARGS_((Tcl_Interp *interp,
-			    int devId, CONST char *buffer, long size));
+void	TkConsolePrint _ANSI_ARGS_((Tcl_Interp *interp,
+			    int devId, char *buffer, long size));
 
 EXTERN void		TkEventInit _ANSI_ARGS_((void));
 
-EXTERN void		TkRegisterObjTypes _ANSI_ARGS_((void));
-
 EXTERN int		TkCreateMenuCmd _ANSI_ARGS_((Tcl_Interp *interp));
 EXTERN int		TkDeadAppCmd _ANSI_ARGS_((ClientData clientData,
-			    Tcl_Interp *interp, int argc, CONST char **argv));
+			    Tcl_Interp *interp, int argc, char **argv));
 
 EXTERN int		TkpTestembedCmd _ANSI_ARGS_((ClientData clientData,
-			    Tcl_Interp *interp, int argc, CONST char **argv));
-EXTERN int		TkCanvasGetCoordObj _ANSI_ARGS_((Tcl_Interp *interp,
-			    Tk_Canvas canvas, Tcl_Obj *obj,
-			    double *doublePtr));
-EXTERN int		TkCanvasDashParseProc _ANSI_ARGS_((
-			    ClientData clientData, Tcl_Interp *interp,
-			    Tk_Window tkwin, CONST char *value, char *widgRec,
-			    int offset));
-EXTERN char *		TkCanvasDashPrintProc _ANSI_ARGS_((
-			    ClientData clientData, Tk_Window tkwin,
-			    char *widgRec, int offset,
-			    Tcl_FreeProc **freeProcPtr));
-EXTERN int		TkGetDoublePixels _ANSI_ARGS_((Tcl_Interp *interp,
-			    Tk_Window tkwin, CONST char *string,
-			    double *doublePtr));
-EXTERN CONST Tk_OptionSpec *
-			TkGetOptionSpec _ANSI_ARGS_((CONST char *name,
-			    Tk_OptionTable optionTable));
-EXTERN int		TkOffsetParseProc _ANSI_ARGS_((
-			    ClientData clientData, Tcl_Interp *interp,
-			    Tk_Window tkwin, CONST char *value, char *widgRec,
-			    int offset));
-EXTERN char *		TkOffsetPrintProc _ANSI_ARGS_((
-			    ClientData clientData, Tk_Window tkwin,
-			    char *widgRec, int offset,
-			    Tcl_FreeProc **freeProcPtr));
-EXTERN int		TkOrientParseProc _ANSI_ARGS_((
-			    ClientData clientData, Tcl_Interp *interp,
-			    Tk_Window tkwin, CONST char *value,
-			    char *widgRec, int offset));
-EXTERN char *		TkOrientPrintProc _ANSI_ARGS_((
-			    ClientData clientData, Tk_Window tkwin,
-			    char *widgRec, int offset,
-			    Tcl_FreeProc **freeProcPtr));
-EXTERN int		TkPixelParseProc _ANSI_ARGS_((
-			    ClientData clientData, Tcl_Interp *interp,
-			    Tk_Window tkwin, CONST char *value, char *widgRec,
-			    int offset));
-EXTERN char *		TkPixelPrintProc _ANSI_ARGS_((
-			    ClientData clientData, Tk_Window tkwin,
-			    char *widgRec, int offset,
-			    Tcl_FreeProc **freeProcPtr));
-EXTERN int		TkPostscriptImage _ANSI_ARGS_((Tcl_Interp *interp,
-			    Tk_Window tkwin, Tk_PostscriptInfo psInfo,
-			    XImage *ximage, int x, int y, int width,
-			    int height));
-EXTERN int		TkSmoothParseProc _ANSI_ARGS_((ClientData clientData,
-			    Tcl_Interp *interp, Tk_Window tkwin,
-			    CONST char *value, char *recordPtr, int offset));
-EXTERN char *		TkSmoothPrintProc _ANSI_ARGS_((ClientData clientData,
-			    Tk_Window tkwin, char *recordPtr, int offset,
-			    Tcl_FreeProc **freeProcPtr));
-EXTERN int		TkStateParseProc _ANSI_ARGS_((
-			    ClientData clientData, Tcl_Interp *interp,
-			    Tk_Window tkwin, CONST char *value,
-			    char *widgRec, int offset));
-EXTERN char *		TkStatePrintProc _ANSI_ARGS_((
-			    ClientData clientData, Tk_Window tkwin,
-			    char *widgRec, int offset,
-			    Tcl_FreeProc **freeProcPtr));
-EXTERN int		TkTileParseProc _ANSI_ARGS_((
-			    ClientData clientData, Tcl_Interp *interp,
-			    Tk_Window tkwin, CONST char *value, char *widgRec,
-			    int offset));
-EXTERN char *		TkTilePrintProc _ANSI_ARGS_((
-			    ClientData clientData, Tk_Window tkwin,
-			    char *widgRec, int offset,
-			    Tcl_FreeProc **freeProcPtr));
+			    Tcl_Interp *interp, int argc, char **argv));
 
 /* 
  * Unsupported commands.
  */
 EXTERN int		TkUnsupported1Cmd _ANSI_ARGS_((ClientData clientData,
-			    Tcl_Interp *interp, int argc, CONST char **argv));
+			    Tcl_Interp *interp, int argc, char **argv));
 
 # undef TCL_STORAGE_CLASS
 # define TCL_STORAGE_CLASS DLLIMPORT
