@@ -1,4 +1,4 @@
-/* $Id: ml_gl.c,v 1.43 2004/04/16 11:07:22 raffalli Exp $ */
+/* $Id: ml_gl.c,v 1.47 2005/10/14 13:35:32 garrigue Exp $ */
 
 #ifdef _WIN32
 #include <wtypes.h>
@@ -202,7 +202,7 @@ CAMLprim value ml_glFog (value param) /* ML */
 	glFogf(GL_FOG_INDEX, Float_val(Field(param,1)));
 	break;
     case MLTAG_color:
-	for (i = 0; i < 4; i++) params[i] = Field(Field(param,1),i);
+      for (i = 0; i < 4; i++) params[i] = Float_val(Field(Field(param,1),i));
 	glFogfv(GL_FOG_COLOR, params);
 	break;
     }
@@ -216,11 +216,28 @@ ML_3 (glFrustum, Pair(arg1,Double_val,Double_val),
       Pair(arg2,Double_val,Double_val), Pair(arg3,Double_val,Double_val))
 
 ML_1_ (glGetString, GLenum_val, copy_string_check)
-ML_2 (glGetDoublev, GLenum_val, Double_raw)	
+ML_2 (glGetDoublev, GLenum_val, Double_raw)
+
+CAMLprim value ml_glGetError(value unit)
+{
+    switch (glGetError()) {
+    case GL_NO_ERROR:       return MLTAG_no_error;
+    case GL_INVALID_ENUM:   return MLTAG_invalid_enum;
+    case GL_INVALID_VALUE:  return MLTAG_invalid_value;
+    case GL_INVALID_OPERATION:  return MLTAG_invalid_operation;
+    case GL_STACK_OVERFLOW: return MLTAG_stack_overflow;
+    case GL_STACK_UNDERFLOW: return MLTAG_stack_underflow;
+    case GL_OUT_OF_MEMORY:  return MLTAG_out_of_memory;
+#if defined(GL_VERSION_1_2) || defined(GL_TABLE_TOO_LARGE)
+    case GL_TABLE_TOO_LARGE: return MLTAG_table_too_large;
+#endif
+    default: ml_raise_gl("glGetError: unknown error");
+    }
+}
 	
 CAMLprim value ml_glHint (value target, value hint)
 {
-    GLenum targ;
+    GLenum targ = 0U;
 
     switch (target) {
     case MLTAG_fog:	targ = GL_FOG_HINT; break;
@@ -324,8 +341,8 @@ ML_1 (glLogicOp, GLenum_val)
 
 CAMLprim value ml_glMap1d (value target, value *u, value order, value raw)
 {
-    int ustride, i;
-    GLenum targ;
+    int ustride = 0;
+    GLenum targ = 0U;
 
     switch (target) {
     case MLTAG_vertex_3:
@@ -355,8 +372,8 @@ CAMLprim value ml_glMap1d (value target, value *u, value order, value raw)
 CAMLprim value ml_glMap2d (value target, value u, value uorder,
                            value v, value vorder, value raw)
 {
-    int ustride;
-    GLenum targ;
+    int ustride = 0;
+    GLenum targ = 0U;
 
     switch (target) {
     case MLTAG_vertex_3:
@@ -531,6 +548,7 @@ CAMLprim value ml_glReadPixels(value x, value y, value w, value h, value format
   glPixelStorei(GL_PACK_ALIGNMENT, 1);
   glReadPixels(Int_val(x),Int_val(y),Int_val(w),Int_val(h),GLenum_val(format),
 	       Type_void_raw(raw));
+  return Val_unit;
 }
 
 ML_bc6 (ml_glReadPixels)
